@@ -10,6 +10,7 @@
 from __future__ import division, unicode_literals, print_function, absolute_import
 
 import copy
+import datetime
 import math
 import operator
 import functools
@@ -44,6 +45,25 @@ class _Exception(Exception):            # pragma: no cover
         self.internal = internal
 
 
+def reduce_dimensions(f):
+    def wrapped(self, *args, **kwargs):
+        result = f(self, *args, **kwargs)
+        if result._REGISTRY.auto_reduce_dimensions:
+            return result.to_root_units()
+        else:
+            return result
+    return wrapped
+
+
+def ireduce_dimensions(f):
+    def wrapped(self, *args, **kwargs):
+        result = f(self, *args, **kwargs)
+        if result._REGISTRY.auto_reduce_dimensions:
+            result.ito_root_units()
+        return result
+    return wrapped
+
+
 @fix_str_conversions
 class _Quantity(SharedRegistryObject):
     """Implements a class to describe a physical quantity:
@@ -635,13 +655,18 @@ class _Quantity(SharedRegistryObject):
         return self.__class__(magnitude, units)
 
     def __iadd__(self, other):
-        if not isinstance(self._magnitude, ndarray):
+        if isinstance(other, datetime.datetime):
+            return self.to_timedelta() + other
+        elif not isinstance(self._magnitude, ndarray):
             return self._add_sub(other, operator.add)
         else:
             return self._iadd_sub(other, operator.iadd)
 
     def __add__(self, other):
-        return self._add_sub(other, operator.add)
+        if isinstance(other, datetime.datetime):
+            return self.to_timedelta() + other
+        else:
+            return self._add_sub(other, operator.add)
 
     __radd__ = __add__
 
@@ -655,8 +680,12 @@ class _Quantity(SharedRegistryObject):
         return self._add_sub(other, operator.sub)
 
     def __rsub__(self, other):
-        return -self._add_sub(other, operator.sub)
+        if isinstance(other, datetime.datetime):
+            return other - self.to_timedelta()
+        else:
+            return -self._add_sub(other, operator.sub)
 
+    @ireduce_dimensions
     def _imul_div(self, other, magnitude_op, units_op=None):
         """Perform multiplication or division operation in-place and return the
         result.
@@ -714,6 +743,7 @@ class _Quantity(SharedRegistryObject):
 
         return self
 
+    @reduce_dimensions
     def _mul_div(self, other, magnitude_op, units_op=None):
         """Perform multiplication or division operation and return the result.
 
@@ -1490,6 +1520,9 @@ class _Quantity(SharedRegistryObject):
                 is_ok = False
         return is_ok
 
+    def to_timedelta(self):
+        return datetime.timedelta(microseconds=self.to('microseconds').magnitude)
+
 
 def build_quantity_class(registry, force_ndarray=False):
 
